@@ -21,8 +21,8 @@ impl ObjFunc for TestObj {
     type Result = f64;
     type Fitness = f64;
 
-    fn fitness(&self, v: &[f64], _: f64) -> Self::Fitness {
-        OFFSET + v[0] * v[0] + 8. * v[1] * v[1] + v[2] * v[2] + v[3] * v[3]
+    fn fitness(&self, x: &[f64], _: f64) -> Self::Fitness {
+        OFFSET + x[0] * x[0] + 8. * x[1] * x[1] + x[2] * x[2] + x[3] * x[3]
     }
 
     fn result(&self, v: &[f64]) -> Self::Result {
@@ -41,19 +41,19 @@ impl ObjFunc for TestObj {
 fn test<S>()
 where
     S: Setting + Default,
-    S::Algorithm: utility::Algorithm<TestObj>,
+    S::Algorithm: Algorithm<TestObj>,
 {
     let s = Solver::build(S::default())
         .task(|ctx| ctx.best_f - OFFSET < 1e-20)
         .solve(TestObj::default());
     let ans = s.result();
-    let x = s.best_parameters();
+    let xs = s.best_parameters();
     let y = s.best_fitness();
     let report = s.report();
-    assert!(report.len() > 0, "{}", report.len());
+    assert!(!report.is_empty(), "{}", report.len());
     assert!((ans - OFFSET).abs() < 1e-20, "{}", ans);
-    for i in 0..4 {
-        assert!(x[i].abs() < 1e-6, "x{} = {}", i, x[i]);
+    for (i, x) in xs.iter().enumerate() {
+        assert!(x.abs() < 1e-6, "x{} = {}", i, x);
     }
     assert_eq!(y.abs(), ans);
 }
